@@ -1,27 +1,22 @@
-context("append_values")
-
 test_that("has correct structure with simple input", {
 
-  skip("wait: testthat")
-    json <- '[{"name": "anne"}, {"name": "bob"}, {"name": "george"}]'
+  json <- '[{"name": "anne"}, {"name": "bob"}, {"name": "george"}]'
 
-    expect_identical(
-      json %>% gather_array %>% gather_object %>%
-        append_values_string,
-      tbl_json(
-        data.frame(
-          document.id = c(1L, 1L, 1L),
-          array.index = 1L:3L,
-          name = rep("name", 3),
-          string = c("anne", "bob", "george"),
-          stringsAsFactors = FALSE
-        ),
-        list(name = "anne", name = "bob", name = "george")
-      )
+  expect_identical(
+    json %>% gather_array %>% gather_object %>%
+      append_values_string,
+    tbl_json(
+      data.frame(
+        document.id = c(1L, 1L, 1L),
+        array.index = 1L:3L,
+        name = rep("name", 3),
+        string = c("anne", "bob", "george"),
+        stringsAsFactors = FALSE
+      ),
+      list(name = "anne", name = "bob", name = "george")
     )
-
-  }
-)
+  )
+})
 
 test_that("string works with value array", {
 
@@ -237,8 +232,6 @@ test_that("works for coerced types", {
   expect_identical(coerce_helper('["a", {"a": "b", "b": "c"}]'), list("a", "a" = "b"))
 })
 
-
-context("my_unlist")
 test_that("my_unlist safely handles edge cases", {
 
     expect_identical(my_unlist(list(1, NA)), c(1, NA_integer_))
